@@ -79,6 +79,48 @@ class ExampleSanity(unittest.TestCase):
     # Show the data and the best fit model
 #     plt.show()
 
+  def sanity_fmin_powell_example(self):
+    """
+    Checking fmin_powell example
+    """
+    # Import numpy and matplotlib
+    from numpy import arange, sqrt, exp, pi, random, ones
+    import matplotlib.pylab as plt
+    # ... and now the funcFit package
+    from PyAstronomy import funcFit as fuf
+    
+    # Creating a Gaussian with some noise
+    # Choose some parameters...
+    gPar = {"A": -5.0, "sig": 10.0, "mu": 10.0, "off": 1.0, "lin": 0.0}
+    # Calculate profile
+    x = arange(100) - 50.0
+    y = gPar["off"] + gPar["A"] / sqrt(2*pi*gPar["sig"]**2) \
+        * exp(-(x-gPar["mu"])**2/(2*gPar["sig"]**2))
+    # Add some noise
+    y += random.normal(0.0, 0.01, x.size)
+    # Let us see what we have done...
+    plt.plot(x, y, 'bp')
+    
+    gf = fuf.GaussFit1d()
+    # Set guess values for the parameters
+    gf["A"] = -1.0
+    gf["sig"] = 12.77
+    gf["off"] = 1.87
+    gf["mu"] = 10.5
+    
+    # Which parameters shall be variable during the fit?
+    # 'Thaw' those (the order is irrelevant)
+    gf.thaw(["A", "sig", "off", "mu"])
+    
+    # Fit using the algorithm scipy.optimize.fmin_powell
+    gf.fit(x, y, yerr=ones(x.size)*0.01, minAlgo="spfmp")
+    
+    # Write the result to the screen and plot the best fit model
+    gf.parameterSummary()
+    plt.plot(x, gf.model, 'r--')
+    
+    # Show the data and the best fit model
+    #plt.show()
 
   def sanity_CustomModel(self):
     # Import numpy and matplotlib
@@ -920,9 +962,9 @@ class MCMCExampleSanity(unittest.TestCase):
     except:
       print("Could not remove file: mcmcExample.tmp")
     try:
-      os.remove("mcmcTA.tmp")
+      os.remove("mcmcTA.emcee")
     except:
-      print("Could not remove file: mcmcTA.tmp")
+      print("Could not remove file: mcmcTA.emcee")
     try:
       os.remove("mcmcSample.tmp")
     except:
@@ -940,235 +982,244 @@ class MCMCExampleSanity(unittest.TestCase):
     except:
       print("Could not remove file: musig.emcee")
 
-  def sanity_MCMCSampler(self):    
-    # Import some required modules
-    from numpy import arange, sqrt, exp, pi, random, ones
-    import matplotlib.pylab as plt
-    import pymc
-    # ... and now the funcFit package
-    from PyAstronomy import funcFit as fuf
-    
-    # Creating a Gaussian with some noise
-    # Choose some parameters...
-    gPar = {"A":-5.0, "sig":10.0, "mu":10.0, "off":1.0, "lin":0.0}
-    # Calculate profile
-    x = arange(100) - 50.0
-    y = gPar["off"] + gPar["A"] / sqrt(2*pi*gPar["sig"]**2) \
-    * exp(-(x-gPar["mu"])**2/(2*gPar["sig"]**2))
-    # Add some noise
-    y += random.normal(0.0, 0.01, x.size)
-    
-    # Now let us come to the fitting
-    # First, we create the Gauss1d fit object
-    gf = fuf.GaussFit1d()
-    # See what parameters are available
-    print("List of available parameters: ", gf.availableParameters())
-    # Set guess values for the parameters
-    gf["A"] = -10.0
-    gf["sig"] = 15.77
-    gf["off"] = 0.87
-    gf["mu"] = 7.5
-    # Let us see whether the assignment worked
-    print("Parameters and guess values: ", gf.parameters())
-    
-    # Which parameters shall be variable during the fit?
-    # 'Thaw' those (the order is irrelevant)
-    gf.thaw(["A", "sig", "off", "mu"])
-    
-    # Now start a simplex fit
-    gf.fit(x,y,yerr=ones(x.size)*0.01)
-    
-    # Obtain the best-fit values derived by the simplex fit.
-    # They are to be used as start values for the MCMC sampling.
-    # Note that 'A' is missing - we will introduce this later.
-    X0 = {"sig":gf["sig"], "off":gf["off"], "mu":gf["mu"]}
-    
-    # Now we specify the limits within which the individual parameters
-    # can be varied (for those parameters listed in the 'X0' dictionary).
-    Lims = {"sig":[-20.,20.], "off":[0.,2.], "mu":[5.,15.]}
-    
-    # For the parameters contained in 'X0', define the step widths, which
-    # are to be used by the MCMC sampler. The steps are specified using
-    # the same scale/units as the actual parameters.
-    steps = {"A":0.01, "sig":0.1, "off":0.1, "mu":0.1}
-    
-    # In this example, we wish to define our ``own'' PyMC variable for the parameter
-    # 'A'. This can be useful, if nonstandard behavior is desired. Note that this
-    # is an optional parameter and you could simply include the parameter 'A' into
-    # The framework of X0, Lims, and steps.
-    ppa = {}
-    ppa["A"] = pymc.Uniform("A", value=gf["A"], lower=-20., \
-                            upper=10.0, doc="Amplitude")
-    
-    # Start the sampling. The resulting Marchov-Chain will be written
-    # to the file 'mcmcExample.tmp'. In default configuration, pickle
-    # is used to write that file.
-    # To save the chain to a compressed 'hdf5'
-    # file, you have to specify the dbArgs keyword; e.g., use:
-    #   dbArgs = {"db":"hdf5", "dbname":"mcmcExample.hdf5"}
-    gf.fitMCMC(x, y, X0, Lims, steps, yerr=ones(x.size)*0.01, \
-                pymcPars=ppa, iter=2500, burn=0, thin=1, \
-                dbfile="mcmcExample.tmp")
-    
-    # Reload the database (here, this is actually not required, but it is
-    # if the Marchov chain is to be analyzed later).
-    db = pymc.database.pickle.load('mcmcExample.tmp')
-    # Plot the trace of the amplitude, 'A'.
-    plt.hist(db.trace("A", 0)[:])
-#     plt.show()
+#===============================================================================
+#   def sanity_MCMCSampler(self):    
+#     # Import some required modules
+#     from numpy import arange, sqrt, exp, pi, random, ones
+#     import matplotlib.pylab as plt
+#     import pymc
+#     # ... and now the funcFit package
+#     from PyAstronomy import funcFit as fuf
+#     
+#     # Creating a Gaussian with some noise
+#     # Choose some parameters...
+#     gPar = {"A":-5.0, "sig":10.0, "mu":10.0, "off":1.0, "lin":0.0}
+#     # Calculate profile
+#     x = arange(100) - 50.0
+#     y = gPar["off"] + gPar["A"] / sqrt(2*pi*gPar["sig"]**2) \
+#     * exp(-(x-gPar["mu"])**2/(2*gPar["sig"]**2))
+#     # Add some noise
+#     y += random.normal(0.0, 0.01, x.size)
+#     
+#     # Now let us come to the fitting
+#     # First, we create the Gauss1d fit object
+#     gf = fuf.GaussFit1d()
+#     # See what parameters are available
+#     print("List of available parameters: ", gf.availableParameters())
+#     # Set guess values for the parameters
+#     gf["A"] = -10.0
+#     gf["sig"] = 15.77
+#     gf["off"] = 0.87
+#     gf["mu"] = 7.5
+#     # Let us see whether the assignment worked
+#     print("Parameters and guess values: ", gf.parameters())
+#     
+#     # Which parameters shall be variable during the fit?
+#     # 'Thaw' those (the order is irrelevant)
+#     gf.thaw(["A", "sig", "off", "mu"])
+#     
+#     # Now start a simplex fit
+#     gf.fit(x,y,yerr=ones(x.size)*0.01)
+#     
+#     # Obtain the best-fit values derived by the simplex fit.
+#     # They are to be used as start values for the MCMC sampling.
+#     # Note that 'A' is missing - we will introduce this later.
+#     X0 = {"sig":gf["sig"], "off":gf["off"], "mu":gf["mu"]}
+#     
+#     # Now we specify the limits within which the individual parameters
+#     # can be varied (for those parameters listed in the 'X0' dictionary).
+#     Lims = {"sig":[-20.,20.], "off":[0.,2.], "mu":[5.,15.]}
+#     
+#     # For the parameters contained in 'X0', define the step widths, which
+#     # are to be used by the MCMC sampler. The steps are specified using
+#     # the same scale/units as the actual parameters.
+#     steps = {"A":0.01, "sig":0.1, "off":0.1, "mu":0.1}
+#     
+#     # In this example, we wish to define our ``own'' PyMC variable for the parameter
+#     # 'A'. This can be useful, if nonstandard behavior is desired. Note that this
+#     # is an optional parameter and you could simply include the parameter 'A' into
+#     # The framework of X0, Lims, and steps.
+#     ppa = {}
+#     ppa["A"] = pymc.Uniform("A", value=gf["A"], lower=-20., \
+#                             upper=10.0, doc="Amplitude")
+#     
+#     # Start the sampling. The resulting Marchov-Chain will be written
+#     # to the file 'mcmcExample.tmp'. In default configuration, pickle
+#     # is used to write that file.
+#     # To save the chain to a compressed 'hdf5'
+#     # file, you have to specify the dbArgs keyword; e.g., use:
+#     #   dbArgs = {"db":"hdf5", "dbname":"mcmcExample.hdf5"}
+#     gf.fitMCMC(x, y, X0, Lims, steps, yerr=ones(x.size)*0.01, \
+#                 pymcPars=ppa, iter=2500, burn=0, thin=1, \
+#                 dbfile="mcmcExample.tmp")
+#     
+#     # Reload the database (here, this is actually not required, but it is
+#     # if the Marchov chain is to be analyzed later).
+#     db = pymc.database.pickle.load('mcmcExample.tmp')
+#     # Plot the trace of the amplitude, 'A'.
+#     plt.hist(db.trace("A", 0)[:])
+# #     plt.show()
+#===============================================================================
 
 
 
-  def sanity_MCMCPriorExample(self):
-    from PyAstronomy import funcFit as fuf
-    import numpy as np
-    import matplotlib.pylab as plt
-    import pymc
+  #=============================================================================
+  # def sanity_MCMCPriorExample(self):
+  #   from PyAstronomy import funcFit as fuf
+  #   import numpy as np
+  #   import matplotlib.pylab as plt
+  #   import pymc
+  #   
+  #   # Create a Gauss-fit object
+  #   gf = fuf.GaussFit1d()
+  #   
+  #   # Choose some parameters
+  #   gf["A"] = -0.65
+  #   gf["mu"] = 1.0
+  #   gf["lin"] = 0.0
+  #   gf["off"] = 1.1
+  #   gf["sig"] = 0.2
+  #   
+  #   # Simulate data with noise
+  #   x = np.linspace(0., 2., 100)
+  #   y = gf.evaluate(x)
+  #   y += np.random.normal(0, 0.05, len(x))
+  #   
+  #   gf.thaw(["A", "off", "mu", "sig"])
+  #   
+  #   # Set up a normal prior for the offset parameter
+  #   # Note!---The name (first parameter) must correspond to that
+  #   #         of the parameter.
+  #   # The expectation value us set to 0.9 while the width is given
+  #   # as 0.01 (tau = 1/sigma**2). The starting value is specified
+  #   # as 1.0.
+  #   offPar = pymc.Normal("off", mu=0.9, tau=(1./0.01)**2, value=1.0)
+  #   # Use a uniform prior for mu.
+  #   muPar = pymc.Uniform("mu", lower=0.95, upper=0.97, value=0.96)
+  #   
+  #   # Collect the "extra"-variables in a dictionary using
+  #   # their names as keys
+  #   pymcPars = {"mu":muPar, "off":offPar}
+  #   
+  #   # Specify starting values, X0, and limits, lims, for
+  #   # those parameter distributions not given specifically.
+  #   X0 = {"A":gf["A"], "sig":gf["sig"]}
+  #   lims = {"A":[-1.0,0.0], "sig":[0., 1.0]}
+  #   # Still, the steps dictionary has to contain all
+  #   # parameter distributions.
+  #   steps = {"A":0.02, "sig":0.02, "mu":0.01, "off":0.01}
+  #   
+  #   # Carry out the MCMC sampling
+  #   gf.fitMCMC(x, y, X0, lims, steps, yerr=np.ones(len(x))*0.05, \
+  #              pymcPars=pymcPars, burn=1000, iter=3000)
+  #   
+  #   # Setting parameters to mean values
+  #   for p in gf.freeParameters():
+  #     gf[p] = gf.MCMC.trace(p)[:].mean()
+  #   
+  #   # Show the "data" and model in the upper panel
+  #   plt.subplot(2,1,1)
+  #   plt.title("Data and model")
+  #   plt.errorbar(x, y, yerr=np.ones(len(x))*0.05, fmt="bp")
+  #   # Plot lowest deviance solution
+  #   plt.plot(x, gf.evaluate(x), 'r--')
+  #   
+  #   # Show the residuals in the lower panel
+  #   plt.subplot(2,1,2)
+  #   plt.title("Residuals")
+  #   plt.errorbar(x, y-gf.evaluate(x), yerr=np.ones(len(x))*0.05, fmt="bp")
+  #   plt.plot([min(x), max(x)], [0.0,0.0], 'r-')
+  #   
+  #   #plt.show()
+  #=============================================================================
     
-    # Create a Gauss-fit object
-    gf = fuf.GaussFit1d()
-    
-    # Choose some parameters
-    gf["A"] = -0.65
-    gf["mu"] = 1.0
-    gf["lin"] = 0.0
-    gf["off"] = 1.1
-    gf["sig"] = 0.2
-    
-    # Simulate data with noise
-    x = np.linspace(0., 2., 100)
-    y = gf.evaluate(x)
-    y += np.random.normal(0, 0.05, len(x))
-    
-    gf.thaw(["A", "off", "mu", "sig"])
-    
-    # Set up a normal prior for the offset parameter
-    # Note!---The name (first parameter) must correspond to that
-    #         of the parameter.
-    # The expectation value us set to 0.9 while the width is given
-    # as 0.01 (tau = 1/sigma**2). The starting value is specified
-    # as 1.0.
-    offPar = pymc.Normal("off", mu=0.9, tau=(1./0.01)**2, value=1.0)
-    # Use a uniform prior for mu.
-    muPar = pymc.Uniform("mu", lower=0.95, upper=0.97, value=0.96)
-    
-    # Collect the "extra"-variables in a dictionary using
-    # their names as keys
-    pymcPars = {"mu":muPar, "off":offPar}
-    
-    # Specify starting values, X0, and limits, lims, for
-    # those parameter distributions not given specifically.
-    X0 = {"A":gf["A"], "sig":gf["sig"]}
-    lims = {"A":[-1.0,0.0], "sig":[0., 1.0]}
-    # Still, the steps dictionary has to contain all
-    # parameter distributions.
-    steps = {"A":0.02, "sig":0.02, "mu":0.01, "off":0.01}
-    
-    # Carry out the MCMC sampling
-    gf.fitMCMC(x, y, X0, lims, steps, yerr=np.ones(len(x))*0.05, \
-               pymcPars=pymcPars, burn=1000, iter=3000)
-    
-    # Setting parameters to mean values
-    for p in gf.freeParameters():
-      gf[p] = gf.MCMC.trace(p)[:].mean()
-    
-    # Show the "data" and model in the upper panel
-    plt.subplot(2,1,1)
-    plt.title("Data and model")
-    plt.errorbar(x, y, yerr=np.ones(len(x))*0.05, fmt="bp")
-    # Plot lowest deviance solution
-    plt.plot(x, gf.evaluate(x), 'r--')
-    
-    # Show the residuals in the lower panel
-    plt.subplot(2,1,2)
-    plt.title("Residuals")
-    plt.errorbar(x, y-gf.evaluate(x), yerr=np.ones(len(x))*0.05, fmt="bp")
-    plt.plot([min(x), max(x)], [0.0,0.0], 'r-')
-    
-    #plt.show()
-    
-  def sanity_autoMCMCExample1(self):
-    from PyAstronomy import funcFit as fuf
-    import numpy as np
-    import matplotlib.pylab as plt
-    
-    x = np.linspace(0,30,1000)
-    gauss = fuf.GaussFit1d()
-    gauss["A"] = 1
-    gauss["mu"] = 23.
-    gauss["sig"] = 0.5
-    # Generate some "data" to fit
-    yerr = np.random.normal(0., 0.05, len(x))
-    y = gauss.evaluate(x) + yerr
-    # Thaw the parameters A, mu, and sig
-    gauss.thaw(["A","mu","sig"])
-    
-    # Define the ranges, which are used to construct the
-    # uniform priors and step sizes.
-    # Note that for "sig", we give only a single value.
-    # In this case, the limits for the uniform prior will
-    # be constructed as [m0-1.5, m0+1.5], where m0 is the
-    # starting value interpreted as the current value of
-    # mu (23. in this case).
-    ranges = {"A":[0,10],"mu":3, "sig":[0.1,1.0]}
-    # Generate default input for X0, lims, and steps
-    X0, lims, steps = gauss.MCMCautoParameters(ranges)
-    
-    # Show what happened...
-    print()
-    print("Auto-generated input parameters:")
-    print("X0: ", X0)
-    print("lims: ", lims)
-    print("steps: ", steps)
-    print()
-    # Call the usual sampler
-    gauss.fitMCMC(x, y, X0, lims, steps, yerr=yerr, iter=1000)
-    
-    # and plot the results
-    plt.plot(x, y, 'k+')
-    plt.plot(x, gauss.evaluate(x), 'r--')
-#     plt.show()
+#===============================================================================
+#   def sanity_autoMCMCExample1(self):
+#     from PyAstronomy import funcFit as fuf
+#     import numpy as np
+#     import matplotlib.pylab as plt
+#     
+#     x = np.linspace(0,30,1000)
+#     gauss = fuf.GaussFit1d()
+#     gauss["A"] = 1
+#     gauss["mu"] = 23.
+#     gauss["sig"] = 0.5
+#     # Generate some "data" to fit
+#     yerr = np.random.normal(0., 0.05, len(x))
+#     y = gauss.evaluate(x) + yerr
+#     # Thaw the parameters A, mu, and sig
+#     gauss.thaw(["A","mu","sig"])
+#     
+#     # Define the ranges, which are used to construct the
+#     # uniform priors and step sizes.
+#     # Note that for "sig", we give only a single value.
+#     # In this case, the limits for the uniform prior will
+#     # be constructed as [m0-1.5, m0+1.5], where m0 is the
+#     # starting value interpreted as the current value of
+#     # mu (23. in this case).
+#     ranges = {"A":[0,10],"mu":3, "sig":[0.1,1.0]}
+#     # Generate default input for X0, lims, and steps
+#     X0, lims, steps = gauss.MCMCautoParameters(ranges)
+#     
+#     # Show what happened...
+#     print()
+#     print("Auto-generated input parameters:")
+#     print("X0: ", X0)
+#     print("lims: ", lims)
+#     print("steps: ", steps)
+#     print()
+#     # Call the usual sampler
+#     gauss.fitMCMC(x, y, X0, lims, steps, yerr=yerr, iter=1000)
+#     
+#     # and plot the results
+#     plt.plot(x, y, 'k+')
+#     plt.plot(x, gauss.evaluate(x), 'r--')
+# #     plt.show()
+#===============================================================================
 
 
-  def sanity_autoMCMCExample2(self):
-    from PyAstronomy import funcFit as fuf
-    import numpy as np
-    import matplotlib.pylab as plt
-    
-    x = np.linspace(0,30,1000)
-    gauss = fuf.GaussFit1d()
-    gauss["A"] = 1
-    gauss["mu"] = 23.
-    gauss["sig"] = 0.5
-    # Generate some "data" to fit
-    yerr = np.random.normal(0., 0.05, len(x))
-    y = gauss.evaluate(x) + yerr
-    
-    # Define the ranges, which are used to construct the
-    # uniform priors and step sizes.
-    # Note that for "sig", we give only a single value.
-    # In this case, the limits for the uniform prior will
-    # be constructed as [m0-1.5, m0+1.5], where m0 is the
-    # starting value interpreted as the current value of
-    # mu (23. in this case).
-    ranges = {"A":[0,10],"mu":3, "sig":[0.1,1.0]}
-    
-    # Call the auto-sampler
-    # Note that we set picky to False here. In this case, the
-    # parameters specified in ranges will be thawed automatically.
-    # All parameters not mentioned there, will be frozen.
-    gauss.autoFitMCMC(x, y, ranges, yerr=yerr, picky=False, iter=1000)
-    
-    # and plot the results
-    plt.plot(x, y, 'k+')
-    plt.plot(x, gauss.evaluate(x), 'r--')
-#    plt.show()
+#===============================================================================
+#   def sanity_autoMCMCExample2(self):
+#     from PyAstronomy import funcFit as fuf
+#     import numpy as np
+#     import matplotlib.pylab as plt
+#     
+#     x = np.linspace(0,30,1000)
+#     gauss = fuf.GaussFit1d()
+#     gauss["A"] = 1
+#     gauss["mu"] = 23.
+#     gauss["sig"] = 0.5
+#     # Generate some "data" to fit
+#     yerr = np.random.normal(0., 0.05, len(x))
+#     y = gauss.evaluate(x) + yerr
+#     
+#     # Define the ranges, which are used to construct the
+#     # uniform priors and step sizes.
+#     # Note that for "sig", we give only a single value.
+#     # In this case, the limits for the uniform prior will
+#     # be constructed as [m0-1.5, m0+1.5], where m0 is the
+#     # starting value interpreted as the current value of
+#     # mu (23. in this case).
+#     ranges = {"A":[0,10],"mu":3, "sig":[0.1,1.0]}
+#     
+#     # Call the auto-sampler
+#     # Note that we set picky to False here. In this case, the
+#     # parameters specified in ranges will be thawed automatically.
+#     # All parameters not mentioned there, will be frozen.
+#     gauss.autoFitMCMC(x, y, ranges, yerr=yerr, picky=False, iter=1000)
+#     
+#     # and plot the results
+#     plt.plot(x, y, 'k+')
+#     plt.plot(x, gauss.evaluate(x), 'r--')
+# #    plt.show()
+#===============================================================================
 
 
   def sanity_TAtut_createTrace(self):
     """
       TA tutorial, all examples
     """
+    # Import some required modules
     import numpy as np
     import matplotlib.pylab as plt
     # ... and now the funcFit package
@@ -1199,7 +1250,7 @@ class MCMCExampleSanity(unittest.TestCase):
     # Plot the data and our guess
     plt.errorbar(x, y, yerr=yerr, fmt='b.-')
     plt.plot(x, vp.evaluate(x), 'r--')
-#    plt.show()
+    plt.show()
     
     # Thaw the parameters, which we wish to vary
     # during the sampling
@@ -1209,34 +1260,21 @@ class MCMCExampleSanity(unittest.TestCase):
     X0 = vp.freeParameters()
     print("Starting point for sampling: ", X0)
     
-    # Now we specify the limits within which the individual parameters
-    # can be varied. Actually, you specify the limits of uniform priors
-    # here.
-    lims = {"A":[-1.0,0.0], "al":[0.0,3.], "ad":[0.0,3.0], "mu":[5495., 5505.]}
+    priors = {"al":fuf.FuFPrior("limuniform", lower=0.0, upper=100.), \
+    "ad":fuf.FuFPrior("limuniform", lower=0.0, upper=100.)}
     
-    # Provide a guess for the proposal step widths.
-    # Try to guess the scale of the problem in the individual
-    # parameters.
-    steps = {"A":0.02, "al":0.01, "ad":0.01, "mu":0.05}
-    
-    # Start the sampling. The resulting Marchov-Chain will be written
-    # to the file 'mcmcTA.tmp'. In default configuration, pickle
-    # is used to write that file.
-    # To save the chain to a compressed 'hdf5'
-    # file, you have to specify the dbArgs keyword; e.g., use:
-    #   dbArgs = {"db":"hdf5", "dbname":"mcmcExample.hdf5"}
-    vp.fitMCMC(x, y, X0, lims, steps, yerr=yerr, \
-               iter=2500, burn=0, thin=1, \
-               dbfile="mcmcTA.tmp")
+    # Note that the filename should end in .emcee. Substitute this filename
+    # in the following examples.
+    vp.fitEMCEE(x, y, yerr=yerr, sampleArgs={"iters":2500}, \
+    dbfile="mcmcTA.emcee", priors=priors)
 
-    
     ######## Second example
     
     from PyAstronomy import funcFit as fuf
     
     # Create an instance of TraceAnalysis
     # telling it which file to use
-    ta = fuf.TraceAnalysis("mcmcTA.tmp")
+    ta = fuf.TraceAnalysis("mcmcTA.emcee")
     
     # Have a look at the deviance to check if and when
     # the chains reached equilibrium.
@@ -1261,7 +1299,7 @@ class MCMCExampleSanity(unittest.TestCase):
     
     # Create an instance of TraceAnalysis
     # telling it which file to use
-    ta = fuf.TraceAnalysis("mcmcTA.tmp")
+    ta = fuf.TraceAnalysis("mcmcTA.emcee")
     
     # Use the burn-in from the previous example
     ta.setBurn(500)
@@ -1285,7 +1323,7 @@ class MCMCExampleSanity(unittest.TestCase):
     
     # Create an instance of TraceAnalysis
     # telling it which file to use
-    ta = fuf.TraceAnalysis("mcmcTA.tmp")
+    ta = fuf.TraceAnalysis("mcmcTA.emcee")
     
     # Use the burn-in from the previous example
     ta.setBurn(500)
@@ -1313,7 +1351,7 @@ class MCMCExampleSanity(unittest.TestCase):
     
     # Create an instance of TraceAnalysis
     # telling it which file to use
-    ta = fuf.TraceAnalysis("mcmcTA.tmp")
+    ta = fuf.TraceAnalysis("mcmcTA.emcee")
     
     # Use the burn-in from the previous example
     ta.setBurn(500)
@@ -1349,7 +1387,7 @@ class MCMCExampleSanity(unittest.TestCase):
     
     # Create an instance of TraceAnalysis
     # telling it which file to use
-    ta = fuf.TraceAnalysis("mcmcTA.tmp")
+    ta = fuf.TraceAnalysis("mcmcTA.emcee")
     
     # Use the burn-in from the previous example
     ta.setBurn(500)
@@ -1367,26 +1405,28 @@ class MCMCExampleSanity(unittest.TestCase):
     ta.plotCorr(parsList=["mu", "ad", "al"])
 #    ta.show()
 
-  def sanity_MCMCautoParameters(self):
-    """
-      Checking sanity of MCMCautoParameters
-    """
-    from PyAstronomy import funcFit as fuf
-    import numpy as np
-    import matplotlib.pylab as plt
-    
-    x = np.linspace(0,30,1000)
-    gauss = fuf.GaussFit1d()
-    gauss["A"] = 1
-    gauss["mu"] = 23.
-    gauss["sig"] = 0.5
-    yerr = np.random.normal(0., 0.05, len(x))
-    y = gauss.evaluate(x) + yerr
-    # This step is not necessary if <picky>=False in MCMCautoParameters.
-    gauss.thaw(["A","mu","sig"])
-    X0, lims, steps = gauss.MCMCautoParameters({"A":[0,10],"mu":3, "sig":[0.1,1.0]})
-    gauss.fitMCMC(x, y, X0, lims, steps, yerr=yerr, iter=1000)
-    
+  #=============================================================================
+  # def sanity_MCMCautoParameters(self):
+  #   """
+  #     Checking sanity of MCMCautoParameters
+  #   """
+  #   from PyAstronomy import funcFit as fuf
+  #   import numpy as np
+  #   import matplotlib.pylab as plt
+  #   
+  #   x = np.linspace(0,30,1000)
+  #   gauss = fuf.GaussFit1d()
+  #   gauss["A"] = 1
+  #   gauss["mu"] = 23.
+  #   gauss["sig"] = 0.5
+  #   yerr = np.random.normal(0., 0.05, len(x))
+  #   y = gauss.evaluate(x) + yerr
+  #   # This step is not necessary if <picky>=False in MCMCautoParameters.
+  #   gauss.thaw(["A","mu","sig"])
+  #   X0, lims, steps = gauss.MCMCautoParameters({"A":[0,10],"mu":3, "sig":[0.1,1.0]})
+  #   gauss.fitMCMC(x, y, X0, lims, steps, yerr=yerr, iter=1000)
+  #   
+  #=============================================================================
 #     plt.plot(x, y, 'k+')
 #     plt.plot(x, gauss.evaluate(x), 'r--')
 #     plt.show()
@@ -1481,7 +1521,7 @@ class MCMCExampleSanity(unittest.TestCase):
     # Plot the distributions of the chains
     # NOTE: the order of the parameters in the chain object is the same
     #       as the order of the parameters returned by freeParamNames()
-    h = plt.hist(pf.emceeSampler.flatchain[::,0], label="c0", normed=True)
+    h = plt.hist(pf.emceeSampler.flatchain[::,0], label="c0", density=True)
     # Construct "data points" in the middle of the bins
     xhist = (h[1][1:] + h[1][0:-1]) / 2.0
     yhist = h[0]
@@ -1527,7 +1567,7 @@ class MCMCExampleSanity(unittest.TestCase):
     print("Posterior estimate of constant: ", np.mean(pf.emceeSampler.flatchain[::,0]), end=' ')
     print(" +/-", np.std(pf.emceeSampler.flatchain[::,0]))
     
-    plt.hist(pf.emceeSampler.flatchain[::,0], label="c0", normed=True)
+    plt.hist(pf.emceeSampler.flatchain[::,0], label="c0", density=True)
 #     plt.show()
 
 
