@@ -2,7 +2,7 @@ from PyAstronomy import pyaC
 from PyAstronomy.pyasl import _ic, _moduleImportStatus
 
 _modules = ["pizzolato2003", "expCorrRN", "ramirez2005", "stellarAge", "ballesterosBV_T", \
-           "abundances", "spectralClass", "mmscetsTable", "roche", "sysrem"]
+           "abundances", "spectralClass", "mmscetsTable", "roche", "sysrem", "parallactic_angle"]
 
 for m in _modules:
   _moduleImportStatus[(__name__, m)] = pyaC.pyaimportallfrom(m, "PyAstronomy.pyasl.asl.aslExt_1", globals())
