@@ -41,37 +41,37 @@ class NasaExoplanetArchive(pp.PyAUpdateCycle):
     st_dist       Distance to star                     pc
     st_mass       Stellar mass                         Solar
     st_teff       Effective temperature of star        K    
-    st_vsini      Stellar vsin(i)                      km/s 
-    st_logg       Stellar surface gravity              cm/s**2
-    st_acts       Stellar S-Index                           
-    st_vj         Stellar V-band brightness            mag
+    st_vsin       Stellar vsin(i)                      km/s 
+    st_logg       Stellar surface gravity              cm/s**2   
+    sy_vmag       Stellar V-band brightness            mag
+    sy_kmag       Stellar Ks-band brightness           mag 
     ===========   ===================================  ======
     """
 
     def _downloadData(self):
         """
         Download data and store it to file in PyA's data directory.
-        """
-        urlRoot = "http://exoplanetarchive.ipac.caltech.edu/cgi-bin/nstedAPI/nph-nstedAPI?"
-        table = "&table=exoplanets"
-        select = "&select="
-        for v in six.itervalues(self._columns):
-            select = ''.join([select, ',', v[0]])
-        outformat = "&format=csv"
+        """        
+        urlRoot = "https://exoplanetarchive.ipac.caltech.edu/TAP/sync?query="
+        select = "select+"
+        v0s = [v[0] for v in six.itervalues(self._columns)]
+        select += ','.join(v0s)
+        select += "+from+ps"
 
-        url = ''.join((urlRoot, table + select, outformat))
+        url = ''.join((urlRoot, select))
+        print("Requesting URL: ", url)
         self._fs.downloadToFile(url, self.dataFileName, clobber=True, verbose=False,
                                 openMethod=gzip.open)
 
     def __init__(self):
         self.data = None
-        self.dataFileName = os.path.join("pyasl", "resBased", "NEXA.csv.gz")
+        self.dataFileName = os.path.join("pyasl", "resBased", "NEXA.vo.gz")
         configFileName = os.path.join("pyasl", "resBased", "NEXA.cfg")
         pp.PyAUpdateCycle.__init__(self, configFileName, "NEXA")
         # Define columns to select
         # Column name, Description, Unit
         self._columns = {}
-        self._columns[0] = ["pl_hostname", "Name of host star", "", "U15"]
+        self._columns[0] = ["hostname", "Name of host star", "", "U15"]
         self._columns[1] = ["pl_name", "Name of the planet", "", "U15"]
         self._columns[2] = ["pl_letter",
                             "Planet letter (e.g., b, c, d, etc.)", "", "U2"]
@@ -89,16 +89,15 @@ class NasaExoplanetArchive(pp.PyAUpdateCycle):
         self._columns[12] = ["pl_orbincl",
                              "Orbital inclination of planet", "deg", np.float]
         self._columns[13] = ["st_rad", "Stellar radii", "Solar", np.float]
-        self._columns[14] = ["st_dist", "Distance to star", "pc", np.float]
+        self._columns[14] = ["sy_dist", "Distance to star", "pc", np.float]
         self._columns[15] = ["st_mass", "Stellar mass", "Solar", np.float]
         self._columns[16] = ["st_teff",
                              "Effective temperature of star", "K", np.float]
-        self._columns[17] = ["st_vsini", "Stellar vsin(i)", "km/s", np.float]
-        self._columns[18] = ["st_logg",
+        self._columns[17] = ["st_logg",
                              "Stellar surface gravity", "cm/s**2", np.float]
-        self._columns[19] = ["st_acts", "Stellar S-Index", "", np.float]
-        self._columns[20] = [
-            "st_vj", "Stellar V-band brightness", "mag", np.float]
+        self._columns[18] = ["sy_vmag", "Stellar V-band brightness", "mag", np.float]
+        self._columns[19] = ["st_vsin", "Projected stellar rotation speed (vsini)", "km/s", np.float]
+        self._columns[20] = ["sy_kmag", "Stellar Ks-band brightness", "mag", np.float]
         # Check whether data file exists
         self._fs = pp.PyAFS()
 
@@ -118,25 +117,26 @@ class NasaExoplanetArchive(pp.PyAUpdateCycle):
         Trigger download of data.
         """
         self._update(self._downloadData)
-
+     
     def _readData(self):
         """
         Read the data from local file into numpy recarray.
         """
-        r = csv.DictReader(self._fs.requestFile(
-            self.dataFileName, 'rt', gzip.open), delimiter=',')
-        for nplanets, x in enumerate(r):
-            pass
-        r = csv.DictReader(self._fs.requestFile(
-            self.dataFileName, 'rt', gzip.open), delimiter=',')
+        try:
+            from astropy.io.votable import parse
+        except ImportError as e:
+            PE.PyAImportFailure("Could not import astropy.io.votable to read VO table", \
+                                solution="Please install astropy (e.g., via pip install astropy)")
+        if not self._fs.fileExists(self.dataFileName):
+            print("Could not find data file. Initiating download.")
+            self._update(self._downloadData)
+        self.pstable = parse(self._fs.requestFile(
+            self.dataFileName, 'rb', gzip.open)).get_first_table()
+        
         dtype = [(self._columns[x][0], self._columns[x][3])
                  for x in range(len(self._columns))]
-        self.data = np.recarray((nplanets + 1,), dtype=dtype)
-        for i, x in enumerate(r):
-            for k, v in six.iteritems(x):
-                if len(v) == 0:
-                    v = None
-                self.data[k][i] = v
+        
+        self.data = np.rec.array(self.pstable.array)
 
     def availableColumns(self, verbose=True):
         """
